#!/bin/sh

if [ "$1" == '-h' -o "$2" == '--help' ]; then
  echo 'Usage: control.sh [PV_PREFIX DEVICE_NAME AUTO_FILL_DEVICE_NAME]'
  echo 'Parameters:'
  echo '  PV_PREFIX              PV name prefix (default: "sim17bm:")'
  echo '  DEVICE_NAME            Name of Cryojet device (default: "oxfcjet1")'
  echo '  AUTO_FILL_DEVICE_NAME  Name of auto-fill device (default: '
  echo '                         "ilm201_1")'
  echo 'Example: control.sh'
  echo 'Example: control.sh sim17bm: oxfcjet1 ilm201_1'
  exit 0
fi

pvPrefix=sim17bm:
if [ "$1" != '' ]; then pvPrefix="$1"; fi
deviceName=oxfcjet1
if [ "$2" != '' ]; then deviceName="$2"; fi
autoFillDeviceName=ilm201_1
if [ "$3" != '' ]; then autoFillDeviceName="$3"; fi


THIS_SCRIPT_HOME=`dirname "$0"`
cd "$THIS_SCRIPT_HOME"
if [ $? -ne 0 ]; then
  echo "Failed to cd to \"$THIS_SCRIPT_HOME\"." 1>&2
  exit 1
fi
THIS_SCRIPT_HOME=`pwd`
if [ $? -ne 0 ]; then
  echo 'Failed to get current working directory.' 1>&2
  exit 1
fi

cd "../src"
if [ $? -ne 0 ]; then
  echo "Failed to cd to \"$THIS_SCRIPT_HOME/../src\"." 1>&2
  exit 1
fi

oxfordIlm201DisplayPath="$THIS_SCRIPT_HOME/../../oxford-ilm201/src"
export EPICS_DISPLAY_PATH="$oxfordIlm201DisplayPath:$EPICS_DISPLAY_PATH"
exec medm -x \
  -macro "P=${pvPrefix},D=${deviceName},DA=${autoFillDeviceName}" \
  ./oxford-cjet-and-autofill.adl
